@@ -57,10 +57,18 @@
 #' @param version The major version of Bootstrap to use (see [versions()]
 #'   for possible values). Defaults to the currently recommended version
 #'   for new projects (currently Bootstrap 5).
+#' @param preset The name of a theme preset, either a built-in theme provided by
+#'   bslib or a Bootswatch theme (see [builtin_themes()] and
+#'   [bootswatch_themes()] for possible values). This argument takes precedence
+#'   over the `bootswatch` argument and only one `theme` or `bootswatch` can be
+#'   provided. When provided to `bs_theme_update()`, any previous preset theme
+#'   is first removed before the new theme preset is applied. You can use
+#'   `theme = "bootstrap"` to remove any preset theme and to revert to a base
+#'   Bootstrap theme.
 #' @param bootswatch The name of a bootswatch theme (see [bootswatch_themes()]
 #'   for possible values). When provided to `bs_theme_update()`, any previous
 #'   Bootswatch theme is first removed before the new one is applied (use
-#'   `bootswatch = "default"` to effectively remove the Bootswatch theme).
+#'   `bootswatch = "bootstrap"` to effectively remove the Bootswatch theme).
 #' @param ... arguments passed along to [bs_add_variables()].
 #' @param bg A color string for the background.
 #' @param fg A color string for the foreground.
@@ -111,19 +119,26 @@
 #' theme <- bs_add_rules(theme, ".my-class { color: $my-class-color }")
 #'
 #' @export
-bs_theme <- function(version = version_default(), bootswatch = NULL, ...,
+bs_theme <- function(version = version_default(), preset = NULL, ...,
                      bg = NULL, fg = NULL, primary = NULL, secondary = NULL,
                      success = NULL, info = NULL, warning = NULL, danger = NULL,
                      base_font = NULL, code_font = NULL, heading_font = NULL,
-                     font_scale = NULL) {
+                     font_scale = NULL, bootswatch = NULL) {
 
-  theme <- bs_bundle(
-    bs_theme_init(version, bootswatch),
+  preset <- resolve_bs_preset(preset, bootswatch, version = version)
+
+  bundle <- bs_bundle(
+    bs_theme_init(version),
     bootstrap_bundle(version),
-    bootswatch_bundle(bootswatch, version)
+    bs_preset_bundle(preset)
   )
+
+  if (!is.null(preset$type)) {
+    bundle <- add_class(bundle, THEME_PRESET_CLASS)
+  }
+
   bs_theme_update(
-    theme, ...,
+    bundle, ...,
     bg = bg, fg = fg,
     primary = primary,
     secondary = secondary,
@@ -141,25 +156,31 @@ bs_theme <- function(version = version_default(), bootswatch = NULL, ...,
 #' @rdname bs_theme
 #' @param theme a [bs_theme()] object.
 #' @export
-bs_theme_update <- function(theme, ..., bootswatch = NULL, bg = NULL, fg = NULL,
+bs_theme_update <- function(theme, ..., preset = NULL, bg = NULL, fg = NULL,
                             primary = NULL, secondary = NULL, success = NULL,
                             info = NULL, warning = NULL, danger = NULL,
                             base_font = NULL, code_font = NULL, heading_font = NULL,
-                            font_scale = NULL) {
+                            font_scale = NULL, bootswatch = NULL) {
   assert_bs_theme(theme)
 
-  if (!is.null(bootswatch)) {
-    old_swatch <- theme_bootswatch(theme)
-    # You're only allowed one Bootswatch theme!
-    if (length(old_swatch)) {
-      theme <- bs_remove(theme, "bootswatch")
-      class(theme) <- setdiff(class(theme), bootswatch_class(old_swatch))
+  preset <- resolve_bs_preset(preset, bootswatch, version = theme_version(theme))
+
+  if (!is.null(preset)) {
+    theme_has_preset <- inherits(theme, THEME_PRESET_CLASS)
+
+    if (theme_has_preset) {
+      # remove the old preset
+      theme <- bs_remove(theme, theme_preset_info(theme)$type)
+      class(theme) <- setdiff(class(theme), THEME_PRESET_CLASS)
     }
-    if (!identical(bootswatch, "default")) {
-      theme <- add_class(theme, bootswatch_class(bootswatch))
-      theme <- bs_bundle(theme, bootswatch_bundle(bootswatch, theme_version(theme)))
+
+    # Add in the new preset unless vanilla bootstrap was requested
+    if (!identical(preset$name, "bootstrap")) {
+      theme <- add_class(theme, THEME_PRESET_CLASS)
+      theme <- bs_bundle(theme, bs_preset_bundle(preset))
     }
   }
+
   # See R/bs-theme-update.R for the implementation of these
   theme <- bs_base_colors(theme, bg = bg, fg = fg)
   theme <- bs_accent_colors(
@@ -180,13 +201,15 @@ bs_theme_update <- function(theme, ..., bootswatch = NULL, bg = NULL, fg = NULL,
 
 #' @rdname bs_global_theme
 #' @export
-bs_global_theme_update <- function(..., bootswatch = NULL, bg = NULL, fg = NULL,
+bs_global_theme_update <- function(..., preset = NULL, bg = NULL, fg = NULL,
                                    primary = NULL,  secondary = NULL, success = NULL,
                                    info = NULL, warning = NULL, danger = NULL,
-                                   base_font = NULL, code_font = NULL, heading_font = NULL) {
+                                   base_font = NULL, code_font = NULL, heading_font = NULL, bootswatch = NULL) {
   theme <- assert_global_theme("bs_theme_global_update()")
   bs_global_set(bs_theme_update(
     theme, ...,
+    preset = preset,
+    bootswatch = bootswatch,
     bg = bg, fg = fg,
     primary = primary,
     secondary = secondary,
@@ -209,19 +232,23 @@ is_bs_theme <- function(x) {
 
 # Start an empty bundle with special classes that
 # theme_version() & theme_bootswatch() search for
-bs_theme_init <- function(version, bootswatch = NULL) {
-  add_class(
-    sass_layer(defaults = list("bootstrap-version" = version)),
-    c(
-      bootswatch_class(bootswatch),
-      paste0("bs_version_", version),
-      "bs_theme"
+bs_theme_init <- function(version) {
+  init_layer <- sass_layer(
+      defaults = list(
+        "bootstrap-version" = version,
+        "bslib-preset-name" = "null !default",
+        "bslib-preset-type" = "null !default"
+      ),
+      rules = c(
+        ":root {",
+        "--bslib-bootstrap-version: #{$bootstrap-version};",
+        "--bslib-preset-name: #{$bslib-preset-name};",
+        "--bslib-preset-type: #{$bslib-preset-type};",
+        "}"
+      )
     )
-  )
-}
 
-bootswatch_class <- function(bootswatch = NULL) {
-  if (is.null(bootswatch)) NULL else paste0("bs_bootswatch_", bootswatch)
+  add_class(init_layer, c(paste0("bs_version_", version), "bs_theme"))
 }
 
 assert_bs_theme <- function(theme) {
@@ -270,21 +297,6 @@ bootstrap_bundle <- function(version) {
       # Additions to BS5 that are always included (i.e., not a part of compatibility)
       sass_layer(rules = pandoc_tables),
       bs3compat = bs3compat_bundle(),
-      sass_layer(
-        mixins = list(
-          sass_file(system_file("components", "_variables.scss", package = "bslib")),
-          sass_file(system_file("components", "_mixins.scss", package = "bslib"))
-        )
-      ),
-      !!!rule_bundles(c(
-        system_file("components", "accordion.scss", package = "bslib"),
-        system_file("components", "card.scss", package = "bslib"),
-        system_file("components", "fill.scss", package = "bslib"),
-        system_file("components", "layout_column_wrap.scss", package = "bslib"),
-        system_file("components", "layout_columns.scss", package = "bslib"),
-        system_file("components", "sidebar.scss", package = "bslib"),
-        system_file("components", "value_box.scss", package = "bslib")
-      )),
       # Enable CSS Grid powered Bootstrap grid
       sass_layer(
         defaults = list("enable-cssgrid" = "true !default")
@@ -332,7 +344,7 @@ bootstrap_bundle <- function(version) {
       glyphicon_font_files = sass_layer(
         defaults = list("icon-font-path" = "'glyphicon-fonts/'"),
         file_attachments = c(
-          "glyphicon-fonts" = lib_file("bs3", "assets", "fonts", "bootstrap")
+          "glyphicon-fonts" = path_lib("bs3", "assets", "fonts", "bootstrap")
         )
       )
     )
@@ -346,29 +358,25 @@ bootstrap_bundle <- function(version) {
     # 2. Allow Bootstrap 3 & 4 to use color-contrast() in variable definitions
     # 3. Allow Bootstrap 3 & 4 to use bs_get_contrast()
     sass_layer(
-      functions = sass_file(system_file("sass-utils/color-contrast.scss", package = "bslib"))
-    ),
-    # nav_spacer() CSS (can be removed)
-    nav_spacer = sass_layer(
-      rules = sass_file(system_file("nav-spacer/nav-spacer.scss", package = "bslib"))
+      functions = sass_file(path_inst("sass-utils/color-contrast.scss")),
+      rules = sass_file(path_inst("bslib-scss", "bslib.scss"))
     )
   )
 }
 
-
 bootstrap_javascript_map <- function(version) {
   switch_version(
     version,
-    five = lib_file("bs5", "dist", "js", "bootstrap.bundle.min.js.map"),
-    four = lib_file("bs4", "dist", "js", "bootstrap.bundle.min.js.map")
+    five = path_lib("bs5", "dist", "js", "bootstrap.bundle.min.js.map"),
+    four = path_lib("bs4", "dist", "js", "bootstrap.bundle.min.js.map")
   )
 }
 bootstrap_javascript <- function(version) {
   switch_version(
     version,
-    five = lib_file("bs5", "dist", "js", "bootstrap.bundle.min.js"),
-    four = lib_file("bs4", "dist", "js", "bootstrap.bundle.min.js"),
-    three = lib_file("bs3", "assets", "javascripts", "bootstrap.min.js")
+    five = path_lib("bs5", "dist", "js", "bootstrap.bundle.min.js"),
+    four = path_lib("bs4", "dist", "js", "bootstrap.bundle.min.js"),
+    three = path_lib("bs3", "assets", "javascripts", "bootstrap.min.js")
   )
 }
 
@@ -384,7 +392,7 @@ bs3compat_bundle <- function() {
     rules = sass_file(system_file("bs3compat", "_rules.scss", package = "bslib")),
     # Gyliphicon font files
     file_attachments = c(
-      fonts = lib_file("bs3", "assets", "fonts")
+      fonts = path_lib("bs3", "assets", "fonts")
     ),
     html_deps = htmltools::htmlDependency(
       "bs3compat", packageVersion("bslib"),
@@ -416,107 +424,3 @@ bs3_accessibility_bundle <- function() {
     )
   )
 }
-
-# -----------------------------------------------------------------
-# Bootswatch bundle
-# -----------------------------------------------------------------
-
-bootswatch_bundle <- function(bootswatch, version) {
-  if (!length(bootswatch) || isTRUE(bootswatch %in% c("default", "bootstrap"))) {
-    return(NULL)
-  }
-
-  bootswatch <- switch_version(
-    version,
-    default = {
-      switch(
-        bootswatch,
-        paper = {
-          message("Bootswatch 3 theme paper has been renamed to materia in version 4 (using that theme instead)")
-          "materia"
-        },
-        readable = {
-          message("Bootswatch 3 theme readable has been renamed to litera in version 4 (using that theme instead)")
-          "litera"
-        },
-        match.arg(bootswatch, bootswatch_themes(version))
-      )
-    },
-    three = match.arg(bootswatch, bootswatch_themes(version))
-  )
-
-  # Attach local font files, if necessary
-  font_css <- file.path(bootswatch_dist(version), bootswatch, "font.css")
-  attachments <- if (file.exists(font_css)) {
-    c(
-      "font.css" = font_css,
-      fonts = system_file("fonts", package = "bslib")
-    )
-  }
-
-  sass_bundle(
-    bootswatch = sass_layer(
-      file_attachments = attachments,
-      defaults = list(
-        # Use local fonts (this path is relative to the bootstrap HTML dependency dir)
-        '$web-font-path: "font.css" !default;',
-        bootswatch_sass_file(bootswatch, "variables", version),
-        # Unless we change navbarPage()'s markup, BS4+ will likely want BS3 compatibility
-        switch_version(
-          version, three = "", default = bs3compat_navbar_defaults(bootswatch)
-        )
-      ),
-      rules = list(
-        bootswatch_sass_file(bootswatch, "bootswatch", version),
-        # For some reason sketchy sets .dropdown-menu{overflow: hidden}
-        # but this prevents .dropdown-submenu from working properly
-        # https://github.com/rstudio/bootscss/blob/023d455/inst/node_modules/bootswatch/dist/sketchy/_bootswatch.scss#L204
-        if (identical(bootswatch, "sketchy")) ".dropdown-menu{ overflow: inherit; }" else "",
-        # Several Bootswatch themes (e.g., zephyr, simplex, etc) add custom .btn-secondary
-        # rules that should also apply to .btn-default
-        ".btn-default:not(.btn-primary):not(.btn-info):not(.btn-success):not(.btn-warning):not(.btn-danger):not(.btn-dark):not(.btn-outline-primary):not(.btn-outline-info):not(.btn-outline-success):not(.btn-outline-warning):not(.btn-outline-danger):not(.btn-outline-dark) {
-          @extend .btn-secondary !optional;
-        }"
-      )
-    )
-  )
-}
-
-
-# Mappings from BS3 navbar classes to BS4
-bs3compat_navbar_defaults <- function(bootswatch) {
-  # Do nothing if this isn't a Bootswatch 3 theme
-  if (!bootswatch %in% c("materia", "litera", bootswatch_themes(3))) {
-    return("")
-  }
-
-  bg_colors <- switch(
-    bootswatch,
-    cerulean = c("primary", "info"),
-    cosmo = c("dark", "primary"),
-    cyborg = c("body-bg", "secondary"),
-    darkly = c("primary", "success"),
-    flatly = c("primary", "success"),
-    journal = c("light", "primary"),
-    lumen = c("light", "white"),
-    # i.e., materia
-    paper = ,
-    materia = c("light", "primary"),
-    readable = ,
-    litera = c("light", "dark"),
-    sandstone = c("dark", "success"),
-    simplex = c("light", "primary"),
-    slate = c("primary", "light"),
-    spacelab = c("light", "primary"),
-    superhero = c("dark", "primary"),
-    united = c("primary", "dark"),
-    yeti = c("dark", "primary"),
-    stop("Didn't recognize Bootswatch 3 theme: ", bootswatch, call. = FALSE)
-  )
-
-
-  list(
-    sprintf('$navbar-light-bg: $%s !default;', bg_colors[1]),
-    sprintf('$navbar-dark-bg: $%s !default;', bg_colors[2])
-  )
-}
