@@ -70,12 +70,21 @@ value_box <- function(title, value, ..., showcase = NULL, showcase_layout = show
     max_height = max_height,
     fill = fill,
     !!!attribs,
-    contents
+    contents,
+    as.card_item(value_box_dependency())
   )
 
   as_fragment(tag_require(res, version = 5, caller = "value_box()"))
 }
 
+value_box_dependency <- function() {
+  bs_dependency_defer(value_box_dependency_sass)
+}
+
+value_box_dependency_sass <- function(theme) {
+  component_dependency_sass(theme, "value_box")
+}
+
 #' @param width one of the following:
 #'   * A proportion (i.e., a number between 0 and 1) of available width to
 #'     allocate to the showcase.
